package authorization

import (
	"encoding/json"
	"errors"

	wxerr "gitee.com/yansen_zh/wxcomponent/errors"
	"gitee.com/yansen_zh/wxcomponent/utils/request"
)

// PushTicketParam 启动票据推送服务参数
type PushTicketParam struct {
	ComponentAppId  string `json:"component_appid"`
	ComponentSecret string `json:"component_secret"`
}

// PushTicketResult 启动票据推送服务参数
type PushTicketResult struct {
	wxerr.Error
}

const (
	apiStartPushTicket = "https://apies.weixin.qq.com/cgi-bin/component/api_start_push_ticket"
)

// StartPushTicket 启动 ticket 推送服务
func StartPushTicket(data PushTicketParam) (*PushTicketResult, error) {
	if data.ComponentAppId == "" {
		return nil, errors.New("启动 ticket 推送服务 第三方平台的 appid 不能为空")
	}

	if data.ComponentSecret == "" {
		return nil, errors.New("启动 ticket 推送服务 第三方平台的 appsecret 不能为空")
	}

	resp, e2 := request.PostJSON(apiStartPushTicket, data)
	if e2 != nil {
		return nil, e2
	}

	result := PushTicketResult{}
	if err := json.Unmarshal(resp, &result); err != nil {
		return nil, err
	}

	if result.Code != 0 {
		return &result, result.Error
	}

	return &result, nil
}
