package authorizer

import (
	"encoding/json"
	"errors"
	"net/url"

	wxerr "gitee.com/yansen_zh/wxcomponent/errors"
	"gitee.com/yansen_zh/wxcomponent/utils/request"
)

// AuthorizerListParam 拉取所有已授权的帐号信息参数
type AuthorizerListParam struct {
	ComponentAppId string `json:"component_appid"`
	Offset         int    `json:"offset"`
	Count          int    `json:"count"`
}

// AuthorizerListResult 拉取所有已授权的帐号信息结果
type AuthorizerListResult struct {
	wxerr.Error
	TotalCount float64               `json:"total_count"`
	List       []AuthorizerBasicInfo `json:"list"`
}

const (
	apiGetAuthorizerList = "https://apies.weixin.qq.com/cgi-bin/component/api_get_authorizer_list"
)

// AuthorizerList 拉取所有已授权的帐号信息
func AuthorizerList(componentAccessToken string, data AuthorizerListParam) (*AuthorizerListResult, error) {
	if componentAccessToken == "" {
		return nil, errors.New("拉取所有已授权的帐号信息 第三方平台的 component_access_token 不能为空")
	}

	if data.ComponentAppId == "" {
		return nil, errors.New("拉取所有已授权的帐号信息 第三方平台的 appid 不能为空")
	}

	if data.Offset < 0 {
		data.Offset = 0
	}

	if data.Count < 0 {
		data.Count = 100
	}

	if data.Count > 500 {
		data.Count = 500
	}

	queryParam := url.Values{}
	queryParam.Set("component_access_token", componentAccessToken)

	apiUrl, _ := request.ParseURL(apiGetAuthorizerList, &queryParam)
	resp, e2 := request.PostJSON(apiUrl.String(), data)
	if e2 != nil {
		return nil, e2
	}

	result := AuthorizerListResult{}
	if err := json.Unmarshal(resp, &result); err != nil {
		return nil, err
	}

	if result.Code != 0 {
		return &result, result.Error
	}

	return &result, nil
}
